==> filesystem-list-parameter-plugin-0.0.1-sources.jar: alex/jenkins/plugins/Messages.java <==
// CHECKSTYLE:OFF

package alex.jenkins.plugins;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No object found in path %s.
     * 
     */
    public static String FileSystemListParameterDefinition_NoObjectsFound() {
        return holder.format("FileSystemListParameterDefinition.NoObjectsFound");
    }

    /**
     * No object found in path %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NoObjectsFound() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NoObjectsFound");
    }

    /**
     * File system objects list Parameter
     * 
     */
    public static String FileSystemListParameterDefinition_DisplayName() {
        return holder.format("FileSystemListParameterDefinition.DisplayName");
    }

    /**
     * File system objects list Parameter
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_DisplayName() {
        return new Localizable(holder, "FileSystemListParameterDefinition.DisplayName");
    }

    /**
     * Name can not be empty
     * 
     */
    public static String FileSystemListParameterDefinition_NameCanNotBeEmpty() {
        return holder.format("FileSystemListParameterDefinition.NameCanNotBeEmpty");
    }

    /**
     * Name can not be empty
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NameCanNotBeEmpty() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NameCanNotBeEmpty");
    }

    /**
     * Path can not be empty
     * 
     */
    public static String FileSystemListParameterDefinition_PathCanNotBeEmpty() {
        return holder.format("FileSystemListParameterDefinition.PathCanNotBeEmpty");
    }

    /**
     * Path can not be empty
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_PathCanNotBeEmpty() {
        return new Localizable(holder, "FileSystemListParameterDefinition.PathCanNotBeEmpty");
    }

    /**
     * Error in symbolic link detection for file %s.
     * 
     */
    public static String FileSystemListParameterDefinition_SymlinkDetectionError() {
        return holder.format("FileSystemListParameterDefinition.SymlinkDetectionError");
    }

    /**
     * Error in symbolic link detection for file %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_SymlinkDetectionError() {
        return new Localizable(holder, "FileSystemListParameterDefinition.SymlinkDetectionError");
    }

    /**
     * [ no objects of type %s found at path %s ]
     * 
     */
    public static String FileSystemListParameterDefinition_NoObjectsFoundAtPath() {
        return holder.format("FileSystemListParameterDefinition.NoObjectsFoundAtPath");
    }

    /**
     * [ no objects of type %s found at path %s ]
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NoObjectsFoundAtPath() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NoObjectsFoundAtPath");
    }

    /**
     * Path %s doesn't seem to exist.
     * 
     */
    public static String FileSystemListParameterDefinition_PathDoesntExist() {
        return holder.format("FileSystemListParameterDefinition.PathDoesntExist");
    }

    /**
     * Path %s doesn't seem to exist.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_PathDoesntExist() {
        return new Localizable(holder, "FileSystemListParameterDefinition.PathDoesntExist");
    }

}

==> filesystem-list-parameter-plugin-0.0.2-sources.jar: alex/jenkins/plugins/Messages.java <==
// CHECKSTYLE:OFF

package alex.jenkins.plugins;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No object found in path %s.
     * 
     */
    public static String FileSystemListParameterDefinition_NoObjectsFound() {
        return holder.format("FileSystemListParameterDefinition.NoObjectsFound");
    }

    /**
     * No object found in path %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NoObjectsFound() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NoObjectsFound");
    }

    /**
     * No valid regular expression '%s'. Fail message: %s.
     * 
     */
    public static String FileSystemListParameterDefinition_RegExPatternNotValid() {
        return holder.format("FileSystemListParameterDefinition.RegExPatternNotValid");
    }

    /**
     * No valid regular expression '%s'. Fail message: %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_RegExPatternNotValid() {
        return new Localizable(holder, "FileSystemListParameterDefinition.RegExPatternNotValid");
    }

    /**
     * File system objects list Parameter
     * 
     */
    public static String FileSystemListParameterDefinition_DisplayName() {
        return holder.format("FileSystemListParameterDefinition.DisplayName");
    }

    /**
     * File system objects list Parameter
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_DisplayName() {
        return new Localizable(holder, "FileSystemListParameterDefinition.DisplayName");
    }

    /**
     * Name can not be empty
     * 
     */
    public static String FileSystemListParameterDefinition_NameCanNotBeEmpty() {
        return holder.format("FileSystemListParameterDefinition.NameCanNotBeEmpty");
    }

    /**
     * Name can not be empty
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NameCanNotBeEmpty() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NameCanNotBeEmpty");
    }

    /**
     * Path can not be empty
     * 
     */
    public static String FileSystemListParameterDefinition_PathCanNotBeEmpty() {
        return holder.format("FileSystemListParameterDefinition.PathCanNotBeEmpty");
    }

    /**
     * Path can not be empty
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_PathCanNotBeEmpty() {
        return new Localizable(holder, "FileSystemListParameterDefinition.PathCanNotBeEmpty");
    }

    /**
     * Error in symbolic link detection for file %s.
     * 
     */
    public static String FileSystemListParameterDefinition_SymlinkDetectionError() {
        return holder.format("FileSystemListParameterDefinition.SymlinkDetectionError");
    }

    /**
     * Error in symbolic link detection for file %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_SymlinkDetectionError() {
        return new Localizable(holder, "FileSystemListParameterDefinition.SymlinkDetectionError");
    }

    /**
     * No objects of type %s and matching include pattern %s and not matching exclude pattern %s found at path %s.
     * 
     */
    public static String FileSystemListParameterDefinition_NoObjectsFoundAtPath() {
        return holder.format("FileSystemListParameterDefinition.NoObjectsFoundAtPath");
    }

    /**
     * No objects of type %s and matching include pattern %s and not matching exclude pattern %s found at path %s.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_NoObjectsFoundAtPath() {
        return new Localizable(holder, "FileSystemListParameterDefinition.NoObjectsFoundAtPath");
    }

    /**
     * Path %s doesn't seem to exist.
     * 
     */
    public static String FileSystemListParameterDefinition_PathDoesntExist() {
        return holder.format("FileSystemListParameterDefinition.PathDoesntExist");
    }

    /**
     * Path %s doesn't seem to exist.
     * 
     */
    public static Localizable _FileSystemListParameterDefinition_PathDoesntExist() {
        return new Localizable(holder, "FileSystemListParameterDefinition.PathDoesntExist");
    }

}
